<?php 

namespace Management\Controllers;

use Management\Services\BranchProfileService;
use Zeedhi\Framework\DTO;
use Doctrine\ORM\EntityManager;

class BranchProfileController {    

    protected $BranchProfileService;

    public function __construct (BranchProfileService $BranchProfileService, $environment, $entityManager) {
        $this->BranchProfileService = $BranchProfileService;
        $this->environment = $environment;
        $this->entityManager    = $entityManager;
    }
    
    private function returnRequestFilter($request) {
        $arr = array();
        foreach ($request->getFilterCriteria()->getConditions() as $condition) {
            $arr[ $condition['columnName'] ] = $condition['value'];  
        }
        return $arr;
    }
    
    public function getProfiles(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->returnRequestFilter($request);
        
        $FILTER = '';
        $NRORG = $conditions['NRORG'];
        $CDOPERADOR = $conditions['CDOPERADOR'];
        if(array_key_exists('NRPERFILACESSO|NMPERFILACESSO', $conditions)){
            $FILTER = $conditions['NRPERFILACESSO|NMPERFILACESSO'][0]['_ALL'];
        }
        $retornoTurnos = $this->BranchProfileService->getRelatedProfiles($CDOPERADOR,$NRORG, $FILTER);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getProfiles', $retornoTurnos));
    }
    
    
    public function getBranches(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->returnRequestFilter($request);
        
        $FILTER = '';
        $NRORG = $conditions['NRORG'];
        $CDOPERADOR = $conditions['CDOPERADOR'];
        $NRPERFILACESSO = $conditions['NRPERFILACESSO'];
        if(array_key_exists('CDFILIAL|NMFILIAL', $conditions)){
            $FILTER = $conditions['CDFILIAL|NMFILIAL'][0]['_ALL'];
        }
        $retornoTurnos = $this->BranchProfileService->getRelatedBranches($NRPERFILACESSO, $CDOPERADOR, $NRORG, $FILTER);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getBranches', $retornoTurnos));
    }
    
    public function save( $request, $response) {
        $row = $request->getRow();
        
        $NRORG = $row['nrorg'];
        $CDOPERADOR = $row['cdoperador'];
        $NRPERFILACESSO = $row['nrperfilacesso'];
        $CDFILIAL = $row['cdfilial'];
        $retornoTurnos = $this->BranchProfileService->updateProfileAndBranch($CDOPERADOR,$NRORG, $NRPERFILACESSO, $CDFILIAL);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('profileAndBranch', []));
    }
    
    public function alterarEstrutura(DTO\Request $request, DTO\Response $response) {
        try {
            $operador = $request->getRow();
            
            $perfil = array_key_exists('PERFIL', $operador) 
                        ? $operador['PERFIL']
                        : null;
            
            $this->alterarEstruturaService(
                $operador['CDFILIAL'], 
                $this->environment->getCdoperador(), 
                $operador['NRORG'], 
                $perfil);
            
            $row = array();
            $row['CDFILIAL']          = $operador['CDFILIAL'];
            $row['CDOPERADOR']        = $this->environment->getCdoperador();
            $row['NRORG']             = $operador['NRORG'];
            $row['ACL_ADMINISTRATOR'] = $this->BranchProfileService->getIsAdministrator($row['CDOPERADOR'], $row['NRORG'], $perfil, $row['CDFILIAL']);
            $dataSet = new \Zeedhi\Framework\DataSource\DataSet('operador', array($row));
            $response->setDataSets(array($dataSet));
        }catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function alterarEstruturaService($cdfilial, $cdoperador, $nrorg, $nrperfilselecionado) {
        $operador = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Operador')
            ->findOneBy(
                array(
                    'cdoperador' => $cdoperador,
                    'nrorg' => $nrorg
                )
            );
        $operador->setNrorgtrab($nrorg);
        
        $operador->setCdfilialselecionada($cdfilial);
        
        $operador->setNrorgselecionada($nrorg);
        $this->entityManager->persist($operador);
        $this->entityManager->flush();
        
        $this->environment->setCdFilial($cdfilial);
        if($this->environment->getIdUtlPerfilFilial() != 'N'){
            $this->environment->setNrPerfil($nrperfilselecionado);
            $this->BranchProfileService->setCdPerfilSelecionado($nrperfilselecionado, $cdoperador, $nrorg);
        }
        
    }
}